@@ -2,7 +2,9 @@
 
 from django import forms
 from django.contrib import admin
-from django.contrib.flatpages.admin import FlatpageForm, FlatPageAdmin
+from django.contrib.flatpages.admin import (
+    FlatpageForm, FlatPageAdmin
+)
 from django.contrib.flatpages.models import FlatPage
 
 from django_markdown.widgets import AdminMarkdownWidget
