@@ -7,4 +7,4 @@ class MarkdownField(models.TextField):
     def formfield(self, **kwargs):
         defaults = {'form_class': MarkdownFormField}
         defaults.update(kwargs)
-        return super(MarkdownField, self).formfield(**defaults)
+        return super().formfield(**defaults)
