@@ -3,7 +3,6 @@ import os
 
 from django import forms
 from django.contrib.admin.widgets import AdminTextareaWidget
-from django.core.files.storage import default_storage
 from django.utils.safestring import mark_safe
 
 from . import settings
@@ -25,15 +24,15 @@ class MarkdownWidget(forms.Textarea):
     """
 
     def __init__(self, attrs=None):
-        super(MarkdownWidget, self).__init__(attrs)
+        super().__init__(attrs)
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         """ Render widget.
 
         :returns: A rendered HTML
 
         """
-        html = super(MarkdownWidget, self).render(name, value, attrs)
+        html = super().render(name, value, attrs)
         attrs = self.build_attrs(attrs)
         html += editor_js_initialization("#%s" % attrs['id'])
         return mark_safe(html)
@@ -41,15 +40,25 @@ class MarkdownWidget(forms.Textarea):
     class Media:
         css = {
             'screen': (
-                os.path.join('django_markdown', 'skins', settings.MARKDOWN_EDITOR_SKIN, 'style.css'),
-                os.path.join(settings.MARKDOWN_SET_PATH, settings.MARKDOWN_SET_NAME, 'style.css')
+                os.path.join(
+                    'django_markdown', 'skins', settings.MARKDOWN_EDITOR_SKIN, 'style.css'
+                ),
+                os.path.join(
+                    settings.MARKDOWN_SET_PATH, settings.MARKDOWN_SET_NAME, 'style.css'
+                )
             )
         }
 
         js = (
-            os.path.join('django_markdown', 'jquery.init.js'),
-            os.path.join('django_markdown', 'jquery.markitup.js'),
-            os.path.join(settings.MARKDOWN_SET_PATH, settings.MARKDOWN_SET_NAME, 'set.js')
+            os.path.join(
+                'django_markdown', 'jquery.init.js'
+            ),
+            os.path.join(
+                'django_markdown', 'jquery.markitup.js'
+            ),
+            os.path.join(
+                settings.MARKDOWN_SET_PATH, settings.MARKDOWN_SET_NAME, 'set.js'
+            )
         )
 
 
